"use strict";
/**
 * Provides a method of converting environment configuration to server
 * configuration.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.configFromEnv = void 0;
function configFromEnv(prefixOrEnv, envOrNothing) {
    // Unwind the overloads
    const prefix = typeof prefixOrEnv === 'string' ? prefixOrEnv : '';
    const env = typeof envOrNothing === 'object' ?
        envOrNothing :
        (typeof prefixOrEnv === 'object' && prefixOrEnv ? prefixOrEnv : process.env);
    const config = {};
    // This basically copies everything that's defined over.
    for (const k in env) {
        const v = env[k];
        if (k.startsWith(prefix)) {
            // Environment keys should be in ALL CAPS but our config keys are lower case
            const configKey = k.substring(prefix.length).toLowerCase();
            if (typeof v !== 'undefined') {
                if (configKey === 'port') {
                    // Special-case: needs to be a number
                    config.port = parseInt(v);
                }
                else {
                    config[configKey] = v;
                }
            }
        }
    }
    return config;
}
exports.configFromEnv = configFromEnv;
