import * as fhir from 'fhir/r4';
import * as mcode from './mcodeextractor';
/**
 * A class that describes the mapping logic of the matching service.
 */
export declare abstract class MappingLogic {
    /**
     * The extracted mcode of the patient bundle.
     */
    private extractedMcode;
    /**
     * Constructor.
     * @param patientBundle
     */
    constructor(patientBundle: fhir.Bundle);
    /**
     * Extracted mCODE getters.
     */
    protected getExtractedPrimaryCancerConditions(): mcode.PrimaryCancerCondition[];
    protected getExtractedSecondaryCancerConditions(): mcode.SecondaryCancerCondition[];
    protected getExtractedTNMclinicalStageGroup(): fhir.Coding[];
    protected getExtractedTNMpathologicalStageGroup(): fhir.Coding[];
    protected getExtractedBirthDate(): string;
    protected getExtractedTumorMarkers(): mcode.TumorMarker[];
    protected getExtractedCancerGeneticVariants(): mcode.CancerGeneticVariant[];
    protected getExtractedCancerRelatedRadiationProcedures(): mcode.CancerRelatedRadiationProcedure[];
    protected getExtractedCancerRelatedSurgicalProcedures(): mcode.CancerRelatedSurgicalProcedure[];
    protected getExtractedCancerRelatedMedicationStatements(): fhir.Coding[];
    protected getExtractedEcogPerformanceStatus(): number;
    protected getExtractedKarnofskyPerformanceStatus(): number;
    /**
     * Required method signatures.
     */
    abstract getPrimaryCancerValues(): string;
    abstract getSecondaryCancerValues(): string[] | string;
    abstract getHistologyMorphologyValue(): string;
    abstract getRadiationProcedureValues(): string[] | string;
    abstract getSurgicalProcedureValues(): string[] | string;
    abstract getAgeValue(): number | string;
    abstract getStageValues(): string | string[];
    abstract getTumorMarkerValues(): string[] | string;
    abstract getMedicationStatementValues(): string[];
    abstract getECOGScore(): number | string;
    abstract getKarnofskyScore(): number | string;
}
